@@ -23,11 +23,15 @@
 #define ADDHOSTDIALOG_H
 
 #include "kdepim_export.h"
-#include <qdialog.h>
+#include <QDialog>
 
 namespace KLDAP {
 class LdapServer;
 class AddHostDialogPrivate;
+/**
+ * @brief The AddHostDialog class
+ * @author Laurent Montel <montel@kde.org>
+ */
 class KDEPIM_EXPORT AddHostDialog : public QDialog
 {
     Q_OBJECT
