@@ -45,16 +45,14 @@
 #include <QClipboard>
 
 #include <KLineEdit>
-//#include <collection.h>
-//#include <itemcreatejob.h>
 #include <kcombobox.h>
 #include <kconfig.h>
 #include <kconfiggroup.h>
 #include <kcmultidialog.h>
-#include <qdialogbuttonbox.h>
+#include <QDialogButtonBox>
 #include <kldap/ldapobject.h>
 #include <kldap/ldapserver.h>
-#include <qlineedit.h>
+#include <QLineEdit>
 #include <kmessagebox.h>
 
 #include <QLocale>
@@ -240,7 +238,7 @@ public:
         ServerRole = Qt::UserRole + 1
     };
 
-    ContactListModel(QObject *parent)
+    explicit ContactListModel(QObject *parent)
         : QAbstractTableModel(parent)
     {
     }
@@ -315,65 +313,44 @@ public:
         switch (section) {
         case 0:
             return i18n("Full Name");
-            break;
         case 1:
             return i18nc("@title:column Column containing email addresses", "Email");
-            break;
         case 2:
             return i18n("Home Number");
-            break;
         case 3:
             return i18n("Work Number");
-            break;
         case 4:
             return i18n("Mobile Number");
-            break;
         case 5:
             return i18n("Fax Number");
-            break;
         case 6:
             return i18n("Company");
-            break;
         case 7:
             return i18n("Organization");
-            break;
         case 8:
             return i18n("Street");
-            break;
         case 9:
             return i18nc("@title:column Column containing the residential state of the address",
                          "State");
-            break;
         case 10:
             return i18n("Country");
-            break;
         case 11:
             return i18n("Zip Code");
-            break;
         case 12:
             return i18n("Postal Address");
-            break;
         case 13:
             return i18n("City");
-            break;
         case 14:
             return i18n("Department");
-            break;
         case 15:
             return i18n("Description");
-            break;
         case 16:
             return i18n("User ID");
-            break;
         case 17:
             return i18nc("@title:column Column containing title of the person", "Title");
-            break;
         default:
             return QVariant();
-            break;
         }
-
-        return QVariant();
     }
 
     QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const override
@@ -400,64 +377,43 @@ public:
         switch (index.column()) {
         case 0:
             return join(map.value(QStringLiteral("cn")), QStringLiteral(", "));
-            break;
         case 1:
             return join(map.value(QStringLiteral("mail")), QStringLiteral(", "));
-            break;
         case 2:
             return join(map.value(QStringLiteral("homePhone")), QStringLiteral(", "));
-            break;
         case 3:
             return join(map.value(QStringLiteral("telephoneNumber")), QStringLiteral(", "));
-            break;
         case 4:
             return join(map.value(QStringLiteral("mobile")), QStringLiteral(", "));
-            break;
         case 5:
             return join(map.value(QStringLiteral("facsimileTelephoneNumber")), QStringLiteral(", "));
-            break;
         case 6:
             return join(map.value(QStringLiteral("Company")), QStringLiteral(", "));
-            break;
         case 7:
             return join(map.value(QStringLiteral("o")), QStringLiteral(", "));
-            break;
         case 8:
             return join(map.value(QStringLiteral("street")), QStringLiteral(", "));
-            break;
         case 9:
             return join(map.value(QStringLiteral("st")), QStringLiteral(", "));
-            break;
         case 10:
             return join(map.value(QStringLiteral("co")), QStringLiteral(", "));
-            break;
         case 11:
             return join(map.value(QStringLiteral("postalCode")), QStringLiteral(", "));
-            break;
         case 12:
             return join(map.value(QStringLiteral("postalAddress")), QStringLiteral(", "));
-            break;
         case 13:
             return join(map.value(QStringLiteral("l")), QStringLiteral(", "));
-            break;
         case 14:
             return join(map.value(QStringLiteral("department")), QStringLiteral(", "));
-            break;
         case 15:
             return join(map.value(QStringLiteral("description")), QStringLiteral(", "));
-            break;
         case 16:
             return join(map.value(QStringLiteral("uid")), QStringLiteral(", "));
-            break;
         case 17:
             return join(map.value(QStringLiteral("title")), QStringLiteral(", "));
-            break;
         default:
             return QVariant();
-            break;
         }
-
-        return QVariant();
     }
 
 private:
@@ -470,19 +426,6 @@ class Q_DECL_HIDDEN LdapSearchDialog::Private
 public:
     Private(LdapSearchDialog *qq)
         : q(qq)
-        , mNumHosts(0)
-        , mIsConfigured(false)
-        , mFilterCombo(nullptr)
-        , mSearchType(nullptr)
-        , mSearchEdit(nullptr)
-        , mRecursiveCheckbox(nullptr)
-        , mResultView(nullptr)
-        , mSearchButton(nullptr)
-        , mModel(nullptr)
-        , progressIndication(nullptr)
-        , sortproxy(nullptr)
-        , searchLine(nullptr)
-        , user1Button(nullptr)
     {
     }
 
@@ -540,7 +483,7 @@ LdapSearchDialog::LdapSearchDialog(QWidget *parent)
     : QDialog(parent)
     , d(new Private(this))
 {
-    setWindowTitle(i18n("Import Contacts from LDAP"));
+    setWindowTitle(i18nc("@title:window", "Import Contacts from LDAP"));
     QVBoxLayout *mainLayout = new QVBoxLayout(this);
 
     QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Cancel, this);
@@ -561,7 +504,7 @@ LdapSearchDialog::LdapSearchDialog(QWidget *parent)
     mainLayout->addWidget(buttonBox);
 
     QVBoxLayout *topLayout = new QVBoxLayout(page);
-    topLayout->setMargin(0);
+    topLayout->setContentsMargins(0, 0, 0, 0);
 
     QGroupBox *groupBox = new QGroupBox(i18n("Search for Addresses in Directory"),
                                         page);
@@ -637,7 +580,7 @@ LdapSearchDialog::LdapSearchDialog(QWidget *parent)
     d->mResultView->verticalHeader()->hide();
     d->mResultView->setSortingEnabled(true);
     d->mResultView->horizontalHeader()->setSortIndicatorShown(true);
-    connect(d->mResultView, QOverload<const QModelIndex &>::of(&QTableView::clicked), this, [this]() {
+    connect(d->mResultView, qOverload<const QModelIndex &>(&QTableView::clicked), this, [this]() {
         d->slotSelectionChanged();
     });
     topLayout->addWidget(d->mResultView);
@@ -646,7 +589,7 @@ LdapSearchDialog::LdapSearchDialog(QWidget *parent)
     connect(d->mResultView, &QTableView::customContextMenuRequested, this, &LdapSearchDialog::slotCustomContextMenuRequested);
 
     QHBoxLayout *buttonLayout = new QHBoxLayout;
-    buttonLayout->setMargin(0);
+    buttonLayout->setContentsMargins(0, 0, 0, 0);
     topLayout->addLayout(buttonLayout);
 
     d->progressIndication = new KPIM::ProgressIndicatorLabel(i18n("Searching..."));
@@ -669,8 +612,8 @@ LdapSearchDialog::LdapSearchDialog(QWidget *parent)
     d->user1Button->setText(i18n("Add Selected"));
     user2Button->setText(i18n("Configure LDAP Servers..."));
 
-    connect(d->mRecursiveCheckbox, SIGNAL(toggled(bool)),
-            this, SLOT(slotSetScope(bool)));
+    connect(d->mRecursiveCheckbox, &QCheckBox::toggled,
+            this, [this](bool state) { d->slotSetScope(state); });
     connect(d->mSearchButton, SIGNAL(clicked()),
             this, SLOT(slotStartSearch()));
 
@@ -756,7 +699,7 @@ void LdapSearchDialog::Private::restoreSettings()
 
             q->connect(ldapClient, SIGNAL(result(KLDAP::LdapClient,KLDAP::LdapObject)), q, SLOT(slotAddResult(KLDAP::LdapClient,KLDAP::LdapObject)));
             q->connect(ldapClient, SIGNAL(done()), q, SLOT(slotSearchDone()));
-            q->connect(ldapClient, SIGNAL(error(QString)), q, SLOT(slotError(QString)));
+            q->connect(ldapClient, &LdapClient::error, q, [this](const QString &err) {slotError(err);});
 
             mLdapClientList.append(ldapClient);
         }
@@ -934,7 +877,7 @@ void LdapSearchDialog::slotUser2()
     // Configure LDAP servers
 
     QPointer<KCMultiDialog> dialog = new KCMultiDialog(this);
-    dialog->setWindowTitle(i18n("Configure the Address Book LDAP Settings"));
+    dialog->setWindowTitle(i18nc("@title:window", "Configure the Address Book LDAP Settings"));
     dialog->addModule(QStringLiteral("kcmldap.desktop"));
 
     if (dialog->exec()) {   //krazy:exclude=crashy
