@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015-2018 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2019 Montel Laurent <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -24,8 +24,8 @@
 #include <KListWidgetSearchLine>
 #include <QLabel>
 #include <klineedit.h>
-#include <qpushbutton.h>
-#include <qtest.h>
+#include <QPushButton>
+#include <QTest>
 #include <addressline/blacklistbaloocompletion/blacklistbalooemailwarning.h>
 
 BlackListBalooEmailCompletionWidgetTest::BlackListBalooEmailCompletionWidgetTest(QObject *parent)
